@@ -36,7 +36,7 @@ sub AUTOLOAD {
 }
 
 my @methods = qw/insert insert_at update update_at update_all
-  delete delete_at delete_all select select_at count update_or_insert/;
+  delete delete_at delete_all select select_at count/;
 for my $method (@methods) {
     
     my $code =
@@ -49,17 +49,13 @@ for my $method (@methods) {
     my @attrs = qw/table type primary_key bind_type/;
     my @insert_attrs = qw/created_at updated_at/;
     my @update_attrs = qw/updated_at/;
-    my @update_or_insert_attrs = qw/created_at updated_at/;
     my @select_attrs = qw/join/;
     if ($method eq 'insert') { push @attrs, @insert_attrs }
-    elsif ($method eq 'update_or_insert') {
-        push @attrs, @update_or_insert_attrs;
-    }
     elsif ($method eq 'update') { push @attrs, @update_attrs }
     elsif (index($method, 'select') != -1) { push @attrs, @select_attrs }
     
     for my $attr (@attrs) {
-        $code .= "$attr => exists \$self->{$attr} ? \$self->{$attr} : \$self->$attr,";
+        $code .= "exists \$self->{$attr} ? ($attr => \$self->{$attr}) : (),";
     }
     
     $code .= qq/\@_);/ .
@@ -70,6 +66,20 @@ for my $method (@methods) {
     croak $code if $@;
 }
 
+sub update_or_insert {
+    my ($self, $param, %opt) = @_;
+    
+    croak "update_or_insert method need primary_key and id option "
+      unless (defined $opt{id} || defined $self->{id})
+          && (defined $opt{primary_key} || defined $self->{primary_key});
+    
+    my $statement_opt = $opt{option} || {};
+    my $row = $self->select(%opt, %{$statement_opt->{select} || {}})->one;
+    return $row ? $self->update($param, %opt, %{$statement_opt->{update} || {}})
+                : $self->insert($param, %opt, %{$statement_opt->{insert} || {}});
+}
+
+
 sub execute {
     my $self = shift;
     return $self->dbi->execute(
@@ -116,6 +126,13 @@ sub new {
           unless $self->can($attr);
     }
     
+    # Cache
+    for my $attr (qw/dbi table created_at updated_at bind_type join primary_key/) {
+        $self->$attr;
+        $self->{$attr} = undef unless exists $self->{$attr};
+    }
+    $self->columns;
+    
     return $self;
 }
 
